ConfigurationSource

Trait ConfigurationSource 

pub trait ConfigurationSource:
    Value
    + Send
    + Sync {
    // Required methods
    fn get_config(&self) -> &dyn ConfigurationSourceConfig;
    fn get_property_value(
        &self,
        config: &dyn RawPropertyConfig,
    ) -> Option<Box<dyn Value>>;
    fn add_change_listener(&self, listener: ConfigurationSourceChangeListener);
    fn clone_boxed(&self) -> Box<dyn ConfigurationSource>;
    fn to_boxed(self) -> Box<dyn ConfigurationSource>;
}

Required Methods

fn get_config(&self) -> &dyn ConfigurationSourceConfig

fn get_property_value( &self, config: &dyn RawPropertyConfig, ) -> Option<Box<dyn Value>>

get property value acccording to the property config

if property is configured, the value is of type V or can be converted to type V by the converters a value of type V returned

otherwise, None returned

fn add_change_listener(&self, listener: ConfigurationSourceChangeListener)

fn clone_boxed(&self) -> Box<dyn ConfigurationSource>

fn to_boxed(self) -> Box<dyn ConfigurationSource>